Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });

/**
 * A middleware handler that can be passed to TanStack Start's `createMiddleware().server(...)` method as [global middleware](https://tanstack.com/start/latest/docs/framework/react/middleware#global-middleware) for instrumenting server functions.
 */
function sentryGlobalServerMiddlewareHandler() {
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  return function (server) {
    return server.next();
  };
}

/**
 * Wraps a TanStack Start stream handler with Sentry instrumentation that can be passed to `createStartHandler(...)`.
 */
function wrapStreamHandlerWithSentry(handler) {
  return handler;
}

/**
 * Wraps the create root route function with Sentry for server-client tracing with SSR.
 */
function wrapCreateRootRouteWithSentry(createRootRoute) {
  return createRootRoute;
}

exports.sentryGlobalServerMiddlewareHandler = sentryGlobalServerMiddlewareHandler;
exports.wrapCreateRootRouteWithSentry = wrapCreateRootRouteWithSentry;
exports.wrapStreamHandlerWithSentry = wrapStreamHandlerWithSentry;
//# sourceMappingURL=index.js.map
